==> jc-1.4.0.tar.gz: soot/baf/internal/BDupInst.h <==
// public abstract class soot.baf.internal.BDupInst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class b9914bc9f2a73744 soot_baf_internal_BDupInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInst

#include "soot/baf/internal/AbstractInst.h"

#ifndef _JC_soot_baf_internal_BDupInst_H_
#define _JC_soot_baf_internal_BDupInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BDupInst$sub_refs	_jc_soot_baf_internal_BDupInst$sub_refs;
typedef struct _jc_soot_baf_internal_BDupInst$sub_nonrefs	_jc_soot_baf_internal_BDupInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BDupInst$refs	_jc_soot_baf_internal_BDupInst$refs;
typedef struct _jc_soot_baf_internal_BDupInst$nonrefs	_jc_soot_baf_internal_BDupInst$nonrefs;
typedef struct _jc_soot_baf_internal_BDupInst$object	_jc_soot_baf_internal_BDupInst$object;

typedef const struct _jc_soot_baf_internal_BDupInst$vmethods	_jc_soot_baf_internal_BDupInst$vmethods;
typedef const struct _jc_soot_baf_internal_BDupInst$vtable	_jc_soot_baf_internal_BDupInst$vtable;
typedef const struct _jc_soot_baf_internal_BDupInst$vtype	_jc_soot_baf_internal_BDupInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BDupInst$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *);

// Virtual methods
extern void _jc_soot_baf_internal_BDupInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *, struct _jc_object *);
extern jint _jc_soot_baf_internal_BDupInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *);
extern jint _jc_soot_baf_internal_BDupInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *);
extern jint _jc_soot_baf_internal_BDupInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *);
extern jint _jc_soot_baf_internal_BDupInst$method$getOutMachineCount$382bb5439d011100(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BDupInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BDupInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BDupInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BDupInst$method_info$getOutCount$de2aea04cd3e0d65;
extern _jc_method _jc_soot_baf_internal_BDupInst$method_info$getOutMachineCount$382bb5439d011100;

// Virtual methods structure
struct _jc_soot_baf_internal_BDupInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *, struct _jc_object *);
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *);
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *);
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *);
	jint	(*getOutMachineCount$382bb5439d011100)(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *);
};

// Vtable
struct _jc_soot_baf_internal_BDupInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_BDupInst$vmethods	soot_baf_internal_BDupInst;
};

// Vtype
struct _jc_soot_baf_internal_BDupInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BDupInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BDupInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BDupInst$refs {
    _jc_soot_baf_internal_BDupInst$sub_refs	soot_baf_internal_BDupInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BDupInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BDupInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_BDupInst$sub_nonrefs	soot_baf_internal_BDupInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BDupInst$object {
	_jc_soot_baf_internal_BDupInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BDupInst$vtype	*vtype;
	_jc_soot_baf_internal_BDupInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BDupInst$vtype _jc_soot_baf_internal_BDupInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BDupInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BDupInst$class_object;

#endif	/* _JC_soot_baf_internal_BDupInst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/BDupInst.h <==
// public abstract class soot.baf.internal.BDupInst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class b9914bc9f2a73744 soot_baf_internal_BDupInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInst

#include "soot/baf/internal/AbstractInst.h"

#ifndef _JC_soot_baf_internal_BDupInst_H_
#define _JC_soot_baf_internal_BDupInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BDupInst$sub_refs	_jc_soot_baf_internal_BDupInst$sub_refs;
typedef struct _jc_soot_baf_internal_BDupInst$sub_nonrefs	_jc_soot_baf_internal_BDupInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BDupInst$refs	_jc_soot_baf_internal_BDupInst$refs;
typedef struct _jc_soot_baf_internal_BDupInst$nonrefs	_jc_soot_baf_internal_BDupInst$nonrefs;
typedef struct _jc_soot_baf_internal_BDupInst$object	_jc_soot_baf_internal_BDupInst$object;

typedef const struct _jc_soot_baf_internal_BDupInst$vmethods	_jc_soot_baf_internal_BDupInst$vmethods;
typedef const struct _jc_soot_baf_internal_BDupInst$vtable	_jc_soot_baf_internal_BDupInst$vtable;
typedef const struct _jc_soot_baf_internal_BDupInst$vtype	_jc_soot_baf_internal_BDupInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BDupInst$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_baf_internal_BDupInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BDupInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BDupInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BDupInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BDupInst$method$getOutMachineCount$382bb5439d011100(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BDupInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BDupInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BDupInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BDupInst$method_info$getOutCount$de2aea04cd3e0d65;
extern _jc_method _jc_soot_baf_internal_BDupInst$method_info$getOutMachineCount$382bb5439d011100;

// Virtual methods structure
struct _jc_soot_baf_internal_BDupInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *) _JC_JCNI_ATTR;
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutMachineCount$382bb5439d011100)(_jc_env *, struct _jc_soot_baf_internal_BDupInst$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_BDupInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_BDupInst$vmethods	soot_baf_internal_BDupInst;
};

// Vtype
struct _jc_soot_baf_internal_BDupInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BDupInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BDupInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BDupInst$refs {
    _jc_soot_baf_internal_BDupInst$sub_refs	soot_baf_internal_BDupInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BDupInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BDupInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_BDupInst$sub_nonrefs	soot_baf_internal_BDupInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BDupInst$object {
	_jc_soot_baf_internal_BDupInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BDupInst$vtype	*vtype;
	_jc_soot_baf_internal_BDupInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BDupInst$vtype _jc_soot_baf_internal_BDupInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BDupInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BDupInst$class_object;

#endif	/* _JC_soot_baf_internal_BDupInst_H_ */
